# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: profile.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from . import media_and_files_pb2 as media__and__files__pb2
from . import users_pb2 as users__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='profile.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\rprofile.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x13miscellaneous.proto\x1a\x15media_and_files.proto\x1a\x0busers.proto\x1a\x15scalapb/scalapb.proto\"K\n\x0fRequestEditName\x12\x1a\n\x04name\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"r\n\x13RequestEditNickName\x12=\n\x08nickname\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"U\n\x14RequestCheckNickName\x12\x1f\n\x08nickname\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"k\n\x10RequestEditAbout\x12\x39\n\x05\x61\x62out\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"m\n\x11RequestEditAvatar\x12:\n\rfile_location\x18\x01 \x01(\x0b\x32\x14.dialog.FileLocationB\r\x8a\xea\x30\t\n\x07\x63ompact:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"o\n\x12ResponseEditAvatar\x12\x1e\n\x06\x61vatar\x18\x01 \x01(\x0b\x32\x0e.dialog.Avatar\x12\x0b\n\x03seq\x18\x02 \x01(\x05\x12\r\n\x05state\x18\x03 \x01(\x0c:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"3\n\x13RequestRemoveAvatar:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"P\n\x15RequestEditMyTimeZone\x12\x19\n\x02tz\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"k\n\x1fRequestEditMyPreferredLanguages\x12*\n\x13preferred_languages\x18\x01 \x03(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"V\n\x0eRequestEditSex\x12&\n\x03sex\x18\x01 \x01(\x0e\x32\x0b.dialog.SexB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"_\n\x18RequestEditCustomProfile\x12%\n\x0e\x63ustom_profile\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"j\n\x17RequestChangeUserStatus\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32\x12.dialog.UserStatusB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest2\xd4\t\n\x07Profile\x12^\n\x08\x45\x64itName\x12\x17.dialog.RequestEditName\x1a\x13.dialog.ResponseSeq\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/grpc/Profile/EditName:\x01*\x12j\n\x0c\x45\x64itNickName\x12\x1b.dialog.RequestEditNickName\x1a\x13.dialog.ResponseSeq\"(\x82\xd3\xe4\x93\x02\"\"\x1d/v1/grpc/Profile/EditNickName:\x01*\x12n\n\rCheckNickName\x12\x1c.dialog.RequestCheckNickName\x1a\x14.dialog.ResponseBool\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/grpc/Profile/CheckNickName:\x01*\x12\x61\n\tEditAbout\x12\x18.dialog.RequestEditAbout\x1a\x13.dialog.ResponseSeq\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v1/grpc/Profile/EditAbout:\x01*\x12k\n\nEditAvatar\x12\x19.dialog.RequestEditAvatar\x1a\x1a.dialog.ResponseEditAvatar\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/grpc/Profile/EditAvatar:\x01*\x12j\n\x0cRemoveAvatar\x12\x1b.dialog.RequestRemoveAvatar\x1a\x13.dialog.ResponseSeq\"(\x82\xd3\xe4\x93\x02\"\"\x1d/v1/grpc/Profile/RemoveAvatar:\x01*\x12p\n\x0e\x45\x64itMyTimeZone\x12\x1d.dialog.RequestEditMyTimeZone\x1a\x13.dialog.ResponseSeq\"*\x82\xd3\xe4\x93\x02$\"\x1f/v1/grpc/Profile/EditMyTimeZone:\x01*\x12\x8e\x01\n\x18\x45\x64itMyPreferredLanguages\x12\'.dialog.RequestEditMyPreferredLanguages\x1a\x13.dialog.ResponseSeq\"4\x82\xd3\xe4\x93\x02.\")/v1/grpc/Profile/EditMyPreferredLanguages:\x01*\x12[\n\x07\x45\x64itSex\x12\x16.dialog.RequestEditSex\x1a\x13.dialog.ResponseSeq\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/grpc/Profile/EditSex:\x01*\x12y\n\x11\x45\x64itCustomProfile\x12 .dialog.RequestEditCustomProfile\x1a\x13.dialog.ResponseSeq\"-\x82\xd3\xe4\x93\x02\'\"\"/v1/grpc/Profile/EditCustomProfile:\x01*\x12v\n\x10\x43hangeUserStatus\x12\x1f.dialog.RequestChangeUserStatus\x1a\x13.dialog.ResponseSeq\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/Profile/ChangeUserStatus:\x01*B\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,media__and__files__pb2.DESCRIPTOR,users__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_REQUESTEDITNAME = _descriptor.Descriptor(
  name='RequestEditName',
  full_name='dialog.RequestEditName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='dialog.RequestEditName.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=261,
)


_REQUESTEDITNICKNAME = _descriptor.Descriptor(
  name='RequestEditNickName',
  full_name='dialog.RequestEditNickName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nickname', full_name='dialog.RequestEditNickName.nickname', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=377,
)


_REQUESTCHECKNICKNAME = _descriptor.Descriptor(
  name='RequestCheckNickName',
  full_name='dialog.RequestCheckNickName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nickname', full_name='dialog.RequestCheckNickName.nickname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=379,
  serialized_end=464,
)


_REQUESTEDITABOUT = _descriptor.Descriptor(
  name='RequestEditAbout',
  full_name='dialog.RequestEditAbout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='about', full_name='dialog.RequestEditAbout.about', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=466,
  serialized_end=573,
)


_REQUESTEDITAVATAR = _descriptor.Descriptor(
  name='RequestEditAvatar',
  full_name='dialog.RequestEditAvatar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_location', full_name='dialog.RequestEditAvatar.file_location', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=684,
)


_RESPONSEEDITAVATAR = _descriptor.Descriptor(
  name='ResponseEditAvatar',
  full_name='dialog.ResponseEditAvatar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='avatar', full_name='dialog.ResponseEditAvatar.avatar', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.ResponseEditAvatar.seq', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.ResponseEditAvatar.state', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=686,
  serialized_end=797,
)


_REQUESTREMOVEAVATAR = _descriptor.Descriptor(
  name='RequestRemoveAvatar',
  full_name='dialog.RequestRemoveAvatar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=799,
  serialized_end=850,
)


_REQUESTEDITMYTIMEZONE = _descriptor.Descriptor(
  name='RequestEditMyTimeZone',
  full_name='dialog.RequestEditMyTimeZone',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tz', full_name='dialog.RequestEditMyTimeZone.tz', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=852,
  serialized_end=932,
)


_REQUESTEDITMYPREFERREDLANGUAGES = _descriptor.Descriptor(
  name='RequestEditMyPreferredLanguages',
  full_name='dialog.RequestEditMyPreferredLanguages',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preferred_languages', full_name='dialog.RequestEditMyPreferredLanguages.preferred_languages', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=934,
  serialized_end=1041,
)


_REQUESTEDITSEX = _descriptor.Descriptor(
  name='RequestEditSex',
  full_name='dialog.RequestEditSex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sex', full_name='dialog.RequestEditSex.sex', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1043,
  serialized_end=1129,
)


_REQUESTEDITCUSTOMPROFILE = _descriptor.Descriptor(
  name='RequestEditCustomProfile',
  full_name='dialog.RequestEditCustomProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='custom_profile', full_name='dialog.RequestEditCustomProfile.custom_profile', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1131,
  serialized_end=1226,
)


_REQUESTCHANGEUSERSTATUS = _descriptor.Descriptor(
  name='RequestChangeUserStatus',
  full_name='dialog.RequestChangeUserStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='dialog.RequestChangeUserStatus.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1228,
  serialized_end=1334,
)

_REQUESTEDITNICKNAME.fields_by_name['nickname'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTEDITABOUT.fields_by_name['about'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTEDITAVATAR.fields_by_name['file_location'].message_type = media__and__files__pb2._FILELOCATION
_RESPONSEEDITAVATAR.fields_by_name['avatar'].message_type = media__and__files__pb2._AVATAR
_REQUESTEDITSEX.fields_by_name['sex'].enum_type = users__pb2._SEX
_REQUESTCHANGEUSERSTATUS.fields_by_name['status'].message_type = users__pb2._USERSTATUS
DESCRIPTOR.message_types_by_name['RequestEditName'] = _REQUESTEDITNAME
DESCRIPTOR.message_types_by_name['RequestEditNickName'] = _REQUESTEDITNICKNAME
DESCRIPTOR.message_types_by_name['RequestCheckNickName'] = _REQUESTCHECKNICKNAME
DESCRIPTOR.message_types_by_name['RequestEditAbout'] = _REQUESTEDITABOUT
DESCRIPTOR.message_types_by_name['RequestEditAvatar'] = _REQUESTEDITAVATAR
DESCRIPTOR.message_types_by_name['ResponseEditAvatar'] = _RESPONSEEDITAVATAR
DESCRIPTOR.message_types_by_name['RequestRemoveAvatar'] = _REQUESTREMOVEAVATAR
DESCRIPTOR.message_types_by_name['RequestEditMyTimeZone'] = _REQUESTEDITMYTIMEZONE
DESCRIPTOR.message_types_by_name['RequestEditMyPreferredLanguages'] = _REQUESTEDITMYPREFERREDLANGUAGES
DESCRIPTOR.message_types_by_name['RequestEditSex'] = _REQUESTEDITSEX
DESCRIPTOR.message_types_by_name['RequestEditCustomProfile'] = _REQUESTEDITCUSTOMPROFILE
DESCRIPTOR.message_types_by_name['RequestChangeUserStatus'] = _REQUESTCHANGEUSERSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestEditName = _reflection.GeneratedProtocolMessageType('RequestEditName', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTEDITNAME,
  '__module__' : 'profile_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestEditName)
  })
_sym_db.RegisterMessage(RequestEditName)

RequestEditNickName = _reflection.GeneratedProtocolMessageType('RequestEditNickName', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTEDITNICKNAME,
  '__module__' : 'profile_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestEditNickName)
  })
_sym_db.RegisterMessage(RequestEditNickName)

RequestCheckNickName = _reflection.GeneratedProtocolMessageType('RequestCheckNickName', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTCHECKNICKNAME,
  '__module__' : 'profile_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestCheckNickName)
  })
_sym_db.RegisterMessage(RequestCheckNickName)

RequestEditAbout = _reflection.GeneratedProtocolMessageType('RequestEditAbout', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTEDITABOUT,
  '__module__' : 'profile_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestEditAbout)
  })
_sym_db.RegisterMessage(RequestEditAbout)

RequestEditAvatar = _reflection.GeneratedProtocolMessageType('RequestEditAvatar', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTEDITAVATAR,
  '__module__' : 'profile_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestEditAvatar)
  })
_sym_db.RegisterMessage(RequestEditAvatar)

ResponseEditAvatar = _reflection.GeneratedProtocolMessageType('ResponseEditAvatar', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEEDITAVATAR,
  '__module__' : 'profile_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseEditAvatar)
  })
_sym_db.RegisterMessage(ResponseEditAvatar)

RequestRemoveAvatar = _reflection.GeneratedProtocolMessageType('RequestRemoveAvatar', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTREMOVEAVATAR,
  '__module__' : 'profile_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestRemoveAvatar)
  })
_sym_db.RegisterMessage(RequestRemoveAvatar)

RequestEditMyTimeZone = _reflection.GeneratedProtocolMessageType('RequestEditMyTimeZone', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTEDITMYTIMEZONE,
  '__module__' : 'profile_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestEditMyTimeZone)
  })
_sym_db.RegisterMessage(RequestEditMyTimeZone)

RequestEditMyPreferredLanguages = _reflection.GeneratedProtocolMessageType('RequestEditMyPreferredLanguages', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTEDITMYPREFERREDLANGUAGES,
  '__module__' : 'profile_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestEditMyPreferredLanguages)
  })
_sym_db.RegisterMessage(RequestEditMyPreferredLanguages)

RequestEditSex = _reflection.GeneratedProtocolMessageType('RequestEditSex', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTEDITSEX,
  '__module__' : 'profile_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestEditSex)
  })
_sym_db.RegisterMessage(RequestEditSex)

RequestEditCustomProfile = _reflection.GeneratedProtocolMessageType('RequestEditCustomProfile', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTEDITCUSTOMPROFILE,
  '__module__' : 'profile_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestEditCustomProfile)
  })
_sym_db.RegisterMessage(RequestEditCustomProfile)

RequestChangeUserStatus = _reflection.GeneratedProtocolMessageType('RequestChangeUserStatus', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTCHANGEUSERSTATUS,
  '__module__' : 'profile_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestChangeUserStatus)
  })
_sym_db.RegisterMessage(RequestChangeUserStatus)


DESCRIPTOR._options = None
_REQUESTEDITNAME.fields_by_name['name']._options = None
_REQUESTEDITNAME._options = None
_REQUESTEDITNICKNAME.fields_by_name['nickname']._options = None
_REQUESTEDITNICKNAME._options = None
_REQUESTCHECKNICKNAME.fields_by_name['nickname']._options = None
_REQUESTCHECKNICKNAME._options = None
_REQUESTEDITABOUT.fields_by_name['about']._options = None
_REQUESTEDITABOUT._options = None
_REQUESTEDITAVATAR.fields_by_name['file_location']._options = None
_REQUESTEDITAVATAR._options = None
_RESPONSEEDITAVATAR._options = None
_REQUESTREMOVEAVATAR._options = None
_REQUESTEDITMYTIMEZONE.fields_by_name['tz']._options = None
_REQUESTEDITMYTIMEZONE._options = None
_REQUESTEDITMYPREFERREDLANGUAGES.fields_by_name['preferred_languages']._options = None
_REQUESTEDITMYPREFERREDLANGUAGES._options = None
_REQUESTEDITSEX.fields_by_name['sex']._options = None
_REQUESTEDITSEX._options = None
_REQUESTEDITCUSTOMPROFILE.fields_by_name['custom_profile']._options = None
_REQUESTEDITCUSTOMPROFILE._options = None
_REQUESTCHANGEUSERSTATUS.fields_by_name['status']._options = None
_REQUESTCHANGEUSERSTATUS._options = None

_PROFILE = _descriptor.ServiceDescriptor(
  name='Profile',
  full_name='dialog.Profile',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1337,
  serialized_end=2573,
  methods=[
  _descriptor.MethodDescriptor(
    name='EditName',
    full_name='dialog.Profile.EditName',
    index=0,
    containing_service=None,
    input_type=_REQUESTEDITNAME,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=b'\202\323\344\223\002\036\"\031/v1/grpc/Profile/EditName:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EditNickName',
    full_name='dialog.Profile.EditNickName',
    index=1,
    containing_service=None,
    input_type=_REQUESTEDITNICKNAME,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=b'\202\323\344\223\002\"\"\035/v1/grpc/Profile/EditNickName:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CheckNickName',
    full_name='dialog.Profile.CheckNickName',
    index=2,
    containing_service=None,
    input_type=_REQUESTCHECKNICKNAME,
    output_type=miscellaneous__pb2._RESPONSEBOOL,
    serialized_options=b'\202\323\344\223\002#\"\036/v1/grpc/Profile/CheckNickName:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EditAbout',
    full_name='dialog.Profile.EditAbout',
    index=3,
    containing_service=None,
    input_type=_REQUESTEDITABOUT,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=b'\202\323\344\223\002\037\"\032/v1/grpc/Profile/EditAbout:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EditAvatar',
    full_name='dialog.Profile.EditAvatar',
    index=4,
    containing_service=None,
    input_type=_REQUESTEDITAVATAR,
    output_type=_RESPONSEEDITAVATAR,
    serialized_options=b'\202\323\344\223\002 \"\033/v1/grpc/Profile/EditAvatar:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveAvatar',
    full_name='dialog.Profile.RemoveAvatar',
    index=5,
    containing_service=None,
    input_type=_REQUESTREMOVEAVATAR,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=b'\202\323\344\223\002\"\"\035/v1/grpc/Profile/RemoveAvatar:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EditMyTimeZone',
    full_name='dialog.Profile.EditMyTimeZone',
    index=6,
    containing_service=None,
    input_type=_REQUESTEDITMYTIMEZONE,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=b'\202\323\344\223\002$\"\037/v1/grpc/Profile/EditMyTimeZone:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EditMyPreferredLanguages',
    full_name='dialog.Profile.EditMyPreferredLanguages',
    index=7,
    containing_service=None,
    input_type=_REQUESTEDITMYPREFERREDLANGUAGES,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=b'\202\323\344\223\002.\")/v1/grpc/Profile/EditMyPreferredLanguages:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EditSex',
    full_name='dialog.Profile.EditSex',
    index=8,
    containing_service=None,
    input_type=_REQUESTEDITSEX,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=b'\202\323\344\223\002\035\"\030/v1/grpc/Profile/EditSex:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EditCustomProfile',
    full_name='dialog.Profile.EditCustomProfile',
    index=9,
    containing_service=None,
    input_type=_REQUESTEDITCUSTOMPROFILE,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=b'\202\323\344\223\002\'\"\"/v1/grpc/Profile/EditCustomProfile:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChangeUserStatus',
    full_name='dialog.Profile.ChangeUserStatus',
    index=10,
    containing_service=None,
    input_type=_REQUESTCHANGEUSERSTATUS,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=b'\202\323\344\223\002&\"!/v1/grpc/Profile/ChangeUserStatus:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROFILE)

DESCRIPTOR.services_by_name['Profile'] = _PROFILE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: push.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='push.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\npush.proto\x12\x06\x64ialog\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x13miscellaneous.proto\x1a\x15scalapb/scalapb.proto\"x\n\x19RequestRegisterGooglePush\x12 \n\nproject_id\x18\x01 \x01(\x03\x42\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x1b\n\x05token\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"X\n\x1bRequestUnregisterGooglePush\x12\x1b\n\x05token\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x9e\x01\n\x18RequestRegisterApplePush\x12\x1f\n\x08\x61pns_key\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x05token\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12&\n\x0f\x61pns_string_key\x18\x03 \x01(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"W\n\x1aRequestUnregisterApplePush\x12\x1b\n\x05token\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xa1\x01\n\x1bRequestRegisterApplePushKit\x12\x1f\n\x08\x61pns_key\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x05token\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12&\n\x0f\x61pns_string_key\x18\x03 \x01(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"Z\n\x1dRequestUnregisterApplePushKit\x12\x1b\n\x05token\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"|\n\x1dRequestRegisterApplePushToken\x12 \n\tbundle_id\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x05token\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\\\n\x1fRequestUnregisterApplePushToken\x12\x1b\n\x05token\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"[\n\x1eRequestRegisterAvroraPushToken\x12\x1b\n\x05token\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"]\n RequestUnregisterAvroraPushToken\x12\x1b\n\x05token\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest2\xbf\n\n\x04Push\x12z\n\x12RegisterGooglePush\x12!.dialog.RequestRegisterGooglePush\x1a\x14.dialog.ResponseVoid\"+\x82\xd3\xe4\x93\x02%\" /v1/grpc/Push/RegisterGooglePush:\x01*\x12\x80\x01\n\x14UnregisterGooglePush\x12#.dialog.RequestUnregisterGooglePush\x1a\x14.dialog.ResponseVoid\"-\x82\xd3\xe4\x93\x02\'\"\"/v1/grpc/Push/UnregisterGooglePush:\x01*\x12w\n\x11RegisterApplePush\x12 .dialog.RequestRegisterApplePush\x1a\x14.dialog.ResponseVoid\"*\x82\xd3\xe4\x93\x02$\"\x1f/v1/grpc/Push/RegisterApplePush:\x01*\x12}\n\x13UnregisterApplePush\x12\".dialog.RequestUnregisterApplePush\x1a\x14.dialog.ResponseVoid\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/Push/UnregisterApplePush:\x01*\x12\x80\x01\n\x14RegisterApplePushKit\x12#.dialog.RequestRegisterApplePushKit\x1a\x14.dialog.ResponseVoid\"-\x82\xd3\xe4\x93\x02\'\"\"/v1/grpc/Push/RegisterApplePushKit:\x01*\x12\x86\x01\n\x16UnregisterApplePushKit\x12%.dialog.RequestUnregisterApplePushKit\x1a\x14.dialog.ResponseVoid\"/\x82\xd3\xe4\x93\x02)\"$/v1/grpc/Push/UnregisterApplePushKit:\x01*\x12\x86\x01\n\x16RegisterApplePushToken\x12%.dialog.RequestRegisterApplePushToken\x1a\x14.dialog.ResponseVoid\"/\x82\xd3\xe4\x93\x02)\"$/v1/grpc/Push/RegisterApplePushToken:\x01*\x12\x8c\x01\n\x18UnregisterApplePushToken\x12\'.dialog.RequestUnregisterApplePushToken\x1a\x14.dialog.ResponseVoid\"1\x82\xd3\xe4\x93\x02+\"&/v1/grpc/Push/UnregisterApplePushToken:\x01*\x12\x89\x01\n\x17RegisterAvroraPushToken\x12&.dialog.RequestRegisterAvroraPushToken\x1a\x14.dialog.ResponseVoid\"0\x82\xd3\xe4\x93\x02*\"%/v1/grpc/Push/RegisterAvroraPushToken:\x01*\x12\x8f\x01\n\x19UnregisterAvroraPushToken\x12(.dialog.RequestUnregisterAvroraPushToken\x1a\x14.dialog.ResponseVoid\"2\x82\xd3\xe4\x93\x02,\"\'/v1/grpc/Push/UnregisterAvroraPushToken:\x01*B\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_REQUESTREGISTERGOOGLEPUSH = _descriptor.Descriptor(
  name='RequestRegisterGooglePush',
  full_name='dialog.RequestRegisterGooglePush',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='dialog.RequestRegisterGooglePush.project_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='dialog.RequestRegisterGooglePush.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=115,
  serialized_end=235,
)


_REQUESTUNREGISTERGOOGLEPUSH = _descriptor.Descriptor(
  name='RequestUnregisterGooglePush',
  full_name='dialog.RequestUnregisterGooglePush',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='dialog.RequestUnregisterGooglePush.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=237,
  serialized_end=325,
)


_REQUESTREGISTERAPPLEPUSH = _descriptor.Descriptor(
  name='RequestRegisterApplePush',
  full_name='dialog.RequestRegisterApplePush',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='apns_key', full_name='dialog.RequestRegisterApplePush.apns_key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='dialog.RequestRegisterApplePush.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='apns_string_key', full_name='dialog.RequestRegisterApplePush.apns_string_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=486,
)


_REQUESTUNREGISTERAPPLEPUSH = _descriptor.Descriptor(
  name='RequestUnregisterApplePush',
  full_name='dialog.RequestUnregisterApplePush',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='dialog.RequestUnregisterApplePush.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=488,
  serialized_end=575,
)


_REQUESTREGISTERAPPLEPUSHKIT = _descriptor.Descriptor(
  name='RequestRegisterApplePushKit',
  full_name='dialog.RequestRegisterApplePushKit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='apns_key', full_name='dialog.RequestRegisterApplePushKit.apns_key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='dialog.RequestRegisterApplePushKit.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='apns_string_key', full_name='dialog.RequestRegisterApplePushKit.apns_string_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=578,
  serialized_end=739,
)


_REQUESTUNREGISTERAPPLEPUSHKIT = _descriptor.Descriptor(
  name='RequestUnregisterApplePushKit',
  full_name='dialog.RequestUnregisterApplePushKit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='dialog.RequestUnregisterApplePushKit.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=741,
  serialized_end=831,
)


_REQUESTREGISTERAPPLEPUSHTOKEN = _descriptor.Descriptor(
  name='RequestRegisterApplePushToken',
  full_name='dialog.RequestRegisterApplePushToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bundle_id', full_name='dialog.RequestRegisterApplePushToken.bundle_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='dialog.RequestRegisterApplePushToken.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=833,
  serialized_end=957,
)


_REQUESTUNREGISTERAPPLEPUSHTOKEN = _descriptor.Descriptor(
  name='RequestUnregisterApplePushToken',
  full_name='dialog.RequestUnregisterApplePushToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='dialog.RequestUnregisterApplePushToken.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=959,
  serialized_end=1051,
)


_REQUESTREGISTERAVRORAPUSHTOKEN = _descriptor.Descriptor(
  name='RequestRegisterAvroraPushToken',
  full_name='dialog.RequestRegisterAvroraPushToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='dialog.RequestRegisterAvroraPushToken.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1053,
  serialized_end=1144,
)


_REQUESTUNREGISTERAVRORAPUSHTOKEN = _descriptor.Descriptor(
  name='RequestUnregisterAvroraPushToken',
  full_name='dialog.RequestUnregisterAvroraPushToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='dialog.RequestUnregisterAvroraPushToken.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1146,
  serialized_end=1239,
)

DESCRIPTOR.message_types_by_name['RequestRegisterGooglePush'] = _REQUESTREGISTERGOOGLEPUSH
DESCRIPTOR.message_types_by_name['RequestUnregisterGooglePush'] = _REQUESTUNREGISTERGOOGLEPUSH
DESCRIPTOR.message_types_by_name['RequestRegisterApplePush'] = _REQUESTREGISTERAPPLEPUSH
DESCRIPTOR.message_types_by_name['RequestUnregisterApplePush'] = _REQUESTUNREGISTERAPPLEPUSH
DESCRIPTOR.message_types_by_name['RequestRegisterApplePushKit'] = _REQUESTREGISTERAPPLEPUSHKIT
DESCRIPTOR.message_types_by_name['RequestUnregisterApplePushKit'] = _REQUESTUNREGISTERAPPLEPUSHKIT
DESCRIPTOR.message_types_by_name['RequestRegisterApplePushToken'] = _REQUESTREGISTERAPPLEPUSHTOKEN
DESCRIPTOR.message_types_by_name['RequestUnregisterApplePushToken'] = _REQUESTUNREGISTERAPPLEPUSHTOKEN
DESCRIPTOR.message_types_by_name['RequestRegisterAvroraPushToken'] = _REQUESTREGISTERAVRORAPUSHTOKEN
DESCRIPTOR.message_types_by_name['RequestUnregisterAvroraPushToken'] = _REQUESTUNREGISTERAVRORAPUSHTOKEN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestRegisterGooglePush = _reflection.GeneratedProtocolMessageType('RequestRegisterGooglePush', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTREGISTERGOOGLEPUSH,
  '__module__' : 'push_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestRegisterGooglePush)
  })
_sym_db.RegisterMessage(RequestRegisterGooglePush)

RequestUnregisterGooglePush = _reflection.GeneratedProtocolMessageType('RequestUnregisterGooglePush', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTUNREGISTERGOOGLEPUSH,
  '__module__' : 'push_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestUnregisterGooglePush)
  })
_sym_db.RegisterMessage(RequestUnregisterGooglePush)

RequestRegisterApplePush = _reflection.GeneratedProtocolMessageType('RequestRegisterApplePush', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTREGISTERAPPLEPUSH,
  '__module__' : 'push_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestRegisterApplePush)
  })
_sym_db.RegisterMessage(RequestRegisterApplePush)

RequestUnregisterApplePush = _reflection.GeneratedProtocolMessageType('RequestUnregisterApplePush', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTUNREGISTERAPPLEPUSH,
  '__module__' : 'push_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestUnregisterApplePush)
  })
_sym_db.RegisterMessage(RequestUnregisterApplePush)

RequestRegisterApplePushKit = _reflection.GeneratedProtocolMessageType('RequestRegisterApplePushKit', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTREGISTERAPPLEPUSHKIT,
  '__module__' : 'push_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestRegisterApplePushKit)
  })
_sym_db.RegisterMessage(RequestRegisterApplePushKit)

RequestUnregisterApplePushKit = _reflection.GeneratedProtocolMessageType('RequestUnregisterApplePushKit', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTUNREGISTERAPPLEPUSHKIT,
  '__module__' : 'push_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestUnregisterApplePushKit)
  })
_sym_db.RegisterMessage(RequestUnregisterApplePushKit)

RequestRegisterApplePushToken = _reflection.GeneratedProtocolMessageType('RequestRegisterApplePushToken', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTREGISTERAPPLEPUSHTOKEN,
  '__module__' : 'push_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestRegisterApplePushToken)
  })
_sym_db.RegisterMessage(RequestRegisterApplePushToken)

RequestUnregisterApplePushToken = _reflection.GeneratedProtocolMessageType('RequestUnregisterApplePushToken', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTUNREGISTERAPPLEPUSHTOKEN,
  '__module__' : 'push_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestUnregisterApplePushToken)
  })
_sym_db.RegisterMessage(RequestUnregisterApplePushToken)

RequestRegisterAvroraPushToken = _reflection.GeneratedProtocolMessageType('RequestRegisterAvroraPushToken', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTREGISTERAVRORAPUSHTOKEN,
  '__module__' : 'push_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestRegisterAvroraPushToken)
  })
_sym_db.RegisterMessage(RequestRegisterAvroraPushToken)

RequestUnregisterAvroraPushToken = _reflection.GeneratedProtocolMessageType('RequestUnregisterAvroraPushToken', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTUNREGISTERAVRORAPUSHTOKEN,
  '__module__' : 'push_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestUnregisterAvroraPushToken)
  })
_sym_db.RegisterMessage(RequestUnregisterAvroraPushToken)


DESCRIPTOR._options = None
_REQUESTREGISTERGOOGLEPUSH.fields_by_name['project_id']._options = None
_REQUESTREGISTERGOOGLEPUSH.fields_by_name['token']._options = None
_REQUESTREGISTERGOOGLEPUSH._options = None
_REQUESTUNREGISTERGOOGLEPUSH.fields_by_name['token']._options = None
_REQUESTUNREGISTERGOOGLEPUSH._options = None
_REQUESTREGISTERAPPLEPUSH.fields_by_name['apns_key']._options = None
_REQUESTREGISTERAPPLEPUSH.fields_by_name['token']._options = None
_REQUESTREGISTERAPPLEPUSH.fields_by_name['apns_string_key']._options = None
_REQUESTREGISTERAPPLEPUSH._options = None
_REQUESTUNREGISTERAPPLEPUSH.fields_by_name['token']._options = None
_REQUESTUNREGISTERAPPLEPUSH._options = None
_REQUESTREGISTERAPPLEPUSHKIT.fields_by_name['apns_key']._options = None
_REQUESTREGISTERAPPLEPUSHKIT.fields_by_name['token']._options = None
_REQUESTREGISTERAPPLEPUSHKIT.fields_by_name['apns_string_key']._options = None
_REQUESTREGISTERAPPLEPUSHKIT._options = None
_REQUESTUNREGISTERAPPLEPUSHKIT.fields_by_name['token']._options = None
_REQUESTUNREGISTERAPPLEPUSHKIT._options = None
_REQUESTREGISTERAPPLEPUSHTOKEN.fields_by_name['bundle_id']._options = None
_REQUESTREGISTERAPPLEPUSHTOKEN.fields_by_name['token']._options = None
_REQUESTREGISTERAPPLEPUSHTOKEN._options = None
_REQUESTUNREGISTERAPPLEPUSHTOKEN.fields_by_name['token']._options = None
_REQUESTUNREGISTERAPPLEPUSHTOKEN._options = None
_REQUESTREGISTERAVRORAPUSHTOKEN.fields_by_name['token']._options = None
_REQUESTREGISTERAVRORAPUSHTOKEN._options = None
_REQUESTUNREGISTERAVRORAPUSHTOKEN.fields_by_name['token']._options = None
_REQUESTUNREGISTERAVRORAPUSHTOKEN._options = None

_PUSH = _descriptor.ServiceDescriptor(
  name='Push',
  full_name='dialog.Push',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1242,
  serialized_end=2585,
  methods=[
  _descriptor.MethodDescriptor(
    name='RegisterGooglePush',
    full_name='dialog.Push.RegisterGooglePush',
    index=0,
    containing_service=None,
    input_type=_REQUESTREGISTERGOOGLEPUSH,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=b'\202\323\344\223\002%\" /v1/grpc/Push/RegisterGooglePush:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UnregisterGooglePush',
    full_name='dialog.Push.UnregisterGooglePush',
    index=1,
    containing_service=None,
    input_type=_REQUESTUNREGISTERGOOGLEPUSH,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=b'\202\323\344\223\002\'\"\"/v1/grpc/Push/UnregisterGooglePush:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterApplePush',
    full_name='dialog.Push.RegisterApplePush',
    index=2,
    containing_service=None,
    input_type=_REQUESTREGISTERAPPLEPUSH,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=b'\202\323\344\223\002$\"\037/v1/grpc/Push/RegisterApplePush:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UnregisterApplePush',
    full_name='dialog.Push.UnregisterApplePush',
    index=3,
    containing_service=None,
    input_type=_REQUESTUNREGISTERAPPLEPUSH,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=b'\202\323\344\223\002&\"!/v1/grpc/Push/UnregisterApplePush:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterApplePushKit',
    full_name='dialog.Push.RegisterApplePushKit',
    index=4,
    containing_service=None,
    input_type=_REQUESTREGISTERAPPLEPUSHKIT,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=b'\202\323\344\223\002\'\"\"/v1/grpc/Push/RegisterApplePushKit:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UnregisterApplePushKit',
    full_name='dialog.Push.UnregisterApplePushKit',
    index=5,
    containing_service=None,
    input_type=_REQUESTUNREGISTERAPPLEPUSHKIT,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=b'\202\323\344\223\002)\"$/v1/grpc/Push/UnregisterApplePushKit:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterApplePushToken',
    full_name='dialog.Push.RegisterApplePushToken',
    index=6,
    containing_service=None,
    input_type=_REQUESTREGISTERAPPLEPUSHTOKEN,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=b'\202\323\344\223\002)\"$/v1/grpc/Push/RegisterApplePushToken:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UnregisterApplePushToken',
    full_name='dialog.Push.UnregisterApplePushToken',
    index=7,
    containing_service=None,
    input_type=_REQUESTUNREGISTERAPPLEPUSHTOKEN,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=b'\202\323\344\223\002+\"&/v1/grpc/Push/UnregisterApplePushToken:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterAvroraPushToken',
    full_name='dialog.Push.RegisterAvroraPushToken',
    index=8,
    containing_service=None,
    input_type=_REQUESTREGISTERAVRORAPUSHTOKEN,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=b'\202\323\344\223\002*\"%/v1/grpc/Push/RegisterAvroraPushToken:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UnregisterAvroraPushToken',
    full_name='dialog.Push.UnregisterAvroraPushToken',
    index=9,
    containing_service=None,
    input_type=_REQUESTUNREGISTERAVRORAPUSHTOKEN,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=b'\202\323\344\223\002,\"\'/v1/grpc/Push/UnregisterAvroraPushToken:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PUSH)

DESCRIPTOR.services_by_name['Push'] = _PUSH

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import miscellaneous_pb2 as miscellaneous__pb2
from . import profile_pb2 as profile__pb2


class ProfileStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.EditName = channel.unary_unary(
                '/dialog.Profile/EditName',
                request_serializer=profile__pb2.RequestEditName.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.EditNickName = channel.unary_unary(
                '/dialog.Profile/EditNickName',
                request_serializer=profile__pb2.RequestEditNickName.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.CheckNickName = channel.unary_unary(
                '/dialog.Profile/CheckNickName',
                request_serializer=profile__pb2.RequestCheckNickName.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseBool.FromString,
                )
        self.EditAbout = channel.unary_unary(
                '/dialog.Profile/EditAbout',
                request_serializer=profile__pb2.RequestEditAbout.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.EditAvatar = channel.unary_unary(
                '/dialog.Profile/EditAvatar',
                request_serializer=profile__pb2.RequestEditAvatar.SerializeToString,
                response_deserializer=profile__pb2.ResponseEditAvatar.FromString,
                )
        self.RemoveAvatar = channel.unary_unary(
                '/dialog.Profile/RemoveAvatar',
                request_serializer=profile__pb2.RequestRemoveAvatar.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.EditMyTimeZone = channel.unary_unary(
                '/dialog.Profile/EditMyTimeZone',
                request_serializer=profile__pb2.RequestEditMyTimeZone.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.EditMyPreferredLanguages = channel.unary_unary(
                '/dialog.Profile/EditMyPreferredLanguages',
                request_serializer=profile__pb2.RequestEditMyPreferredLanguages.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.EditSex = channel.unary_unary(
                '/dialog.Profile/EditSex',
                request_serializer=profile__pb2.RequestEditSex.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.EditCustomProfile = channel.unary_unary(
                '/dialog.Profile/EditCustomProfile',
                request_serializer=profile__pb2.RequestEditCustomProfile.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.ChangeUserStatus = channel.unary_unary(
                '/dialog.Profile/ChangeUserStatus',
                request_serializer=profile__pb2.RequestChangeUserStatus.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )


class ProfileServicer(object):
    """Missing associated documentation comment in .proto file."""

    def EditName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditNickName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckNickName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditAbout(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditAvatar(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveAvatar(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditMyTimeZone(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditMyPreferredLanguages(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditSex(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditCustomProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangeUserStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProfileServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'EditName': grpc.unary_unary_rpc_method_handler(
                    servicer.EditName,
                    request_deserializer=profile__pb2.RequestEditName.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'EditNickName': grpc.unary_unary_rpc_method_handler(
                    servicer.EditNickName,
                    request_deserializer=profile__pb2.RequestEditNickName.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'CheckNickName': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckNickName,
                    request_deserializer=profile__pb2.RequestCheckNickName.FromString,
                    response_serializer=miscellaneous__pb2.ResponseBool.SerializeToString,
            ),
            'EditAbout': grpc.unary_unary_rpc_method_handler(
                    servicer.EditAbout,
                    request_deserializer=profile__pb2.RequestEditAbout.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'EditAvatar': grpc.unary_unary_rpc_method_handler(
                    servicer.EditAvatar,
                    request_deserializer=profile__pb2.RequestEditAvatar.FromString,
                    response_serializer=profile__pb2.ResponseEditAvatar.SerializeToString,
            ),
            'RemoveAvatar': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveAvatar,
                    request_deserializer=profile__pb2.RequestRemoveAvatar.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'EditMyTimeZone': grpc.unary_unary_rpc_method_handler(
                    servicer.EditMyTimeZone,
                    request_deserializer=profile__pb2.RequestEditMyTimeZone.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'EditMyPreferredLanguages': grpc.unary_unary_rpc_method_handler(
                    servicer.EditMyPreferredLanguages,
                    request_deserializer=profile__pb2.RequestEditMyPreferredLanguages.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'EditSex': grpc.unary_unary_rpc_method_handler(
                    servicer.EditSex,
                    request_deserializer=profile__pb2.RequestEditSex.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'EditCustomProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.EditCustomProfile,
                    request_deserializer=profile__pb2.RequestEditCustomProfile.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'ChangeUserStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangeUserStatus,
                    request_deserializer=profile__pb2.RequestChangeUserStatus.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.Profile', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Profile(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def EditName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Profile/EditName',
            profile__pb2.RequestEditName.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditNickName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Profile/EditNickName',
            profile__pb2.RequestEditNickName.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckNickName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Profile/CheckNickName',
            profile__pb2.RequestCheckNickName.SerializeToString,
            miscellaneous__pb2.ResponseBool.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditAbout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Profile/EditAbout',
            profile__pb2.RequestEditAbout.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditAvatar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Profile/EditAvatar',
            profile__pb2.RequestEditAvatar.SerializeToString,
            profile__pb2.ResponseEditAvatar.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveAvatar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Profile/RemoveAvatar',
            profile__pb2.RequestRemoveAvatar.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditMyTimeZone(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Profile/EditMyTimeZone',
            profile__pb2.RequestEditMyTimeZone.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditMyPreferredLanguages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Profile/EditMyPreferredLanguages',
            profile__pb2.RequestEditMyPreferredLanguages.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditSex(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Profile/EditSex',
            profile__pb2.RequestEditSex.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditCustomProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Profile/EditCustomProfile',
            profile__pb2.RequestEditCustomProfile.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangeUserStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Profile/ChangeUserStatus',
            profile__pb2.RequestChangeUserStatus.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import miscellaneous_pb2 as miscellaneous__pb2
from . import presence_pb2 as presence__pb2


class PresenceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StartTyping = channel.unary_unary(
                '/dialog.Presence/StartTyping',
                request_serializer=presence__pb2.RequestStartTyping.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.StopTyping = channel.unary_unary(
                '/dialog.Presence/StopTyping',
                request_serializer=presence__pb2.RequestStopTyping.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.SetOnline = channel.unary_unary(
                '/dialog.Presence/SetOnline',
                request_serializer=presence__pb2.RequestSetOnline.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.GetUserLastPresence = channel.unary_unary(
                '/dialog.Presence/GetUserLastPresence',
                request_serializer=presence__pb2.RequestGetUserLastPresence.SerializeToString,
                response_deserializer=presence__pb2.ResponseUserLastPresence.FromString,
                )


class PresenceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def StartTyping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopTyping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetOnline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserLastPresence(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PresenceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StartTyping': grpc.unary_unary_rpc_method_handler(
                    servicer.StartTyping,
                    request_deserializer=presence__pb2.RequestStartTyping.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'StopTyping': grpc.unary_unary_rpc_method_handler(
                    servicer.StopTyping,
                    request_deserializer=presence__pb2.RequestStopTyping.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'SetOnline': grpc.unary_unary_rpc_method_handler(
                    servicer.SetOnline,
                    request_deserializer=presence__pb2.RequestSetOnline.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'GetUserLastPresence': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserLastPresence,
                    request_deserializer=presence__pb2.RequestGetUserLastPresence.FromString,
                    response_serializer=presence__pb2.ResponseUserLastPresence.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.Presence', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Presence(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def StartTyping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Presence/StartTyping',
            presence__pb2.RequestStartTyping.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StopTyping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Presence/StopTyping',
            presence__pb2.RequestStopTyping.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetOnline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Presence/SetOnline',
            presence__pb2.RequestSetOnline.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserLastPresence(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Presence/GetUserLastPresence',
            presence__pb2.RequestGetUserLastPresence.SerializeToString,
            presence__pb2.ResponseUserLastPresence.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
